# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from casedev import Casedev, AsyncCasedev
from tests.utils import assert_matches_type
from casedev.types.voice import V1ListVoicesResponse

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestV1:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @parametrize
    def test_method_list_voices(self, client: Casedev) -> None:
        v1 = client.voice.v1.list_voices()
        assert_matches_type(V1ListVoicesResponse, v1, path=["response"])

    @parametrize
    def test_method_list_voices_with_all_params(self, client: Casedev) -> None:
        v1 = client.voice.v1.list_voices(
            category="category",
            collection_id="collection_id",
            include_total_count=True,
            next_page_token="next_page_token",
            page_size=1,
            search="search",
            sort="name",
            sort_direction="asc",
            voice_type="premade",
        )
        assert_matches_type(V1ListVoicesResponse, v1, path=["response"])

    @parametrize
    def test_raw_response_list_voices(self, client: Casedev) -> None:
        response = client.voice.v1.with_raw_response.list_voices()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v1 = response.parse()
        assert_matches_type(V1ListVoicesResponse, v1, path=["response"])

    @parametrize
    def test_streaming_response_list_voices(self, client: Casedev) -> None:
        with client.voice.v1.with_streaming_response.list_voices() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v1 = response.parse()
            assert_matches_type(V1ListVoicesResponse, v1, path=["response"])

        assert cast(Any, response.is_closed) is True


class TestAsyncV1:
    parametrize = pytest.mark.parametrize(
        "async_client", [False, True, {"http_client": "aiohttp"}], indirect=True, ids=["loose", "strict", "aiohttp"]
    )

    @parametrize
    async def test_method_list_voices(self, async_client: AsyncCasedev) -> None:
        v1 = await async_client.voice.v1.list_voices()
        assert_matches_type(V1ListVoicesResponse, v1, path=["response"])

    @parametrize
    async def test_method_list_voices_with_all_params(self, async_client: AsyncCasedev) -> None:
        v1 = await async_client.voice.v1.list_voices(
            category="category",
            collection_id="collection_id",
            include_total_count=True,
            next_page_token="next_page_token",
            page_size=1,
            search="search",
            sort="name",
            sort_direction="asc",
            voice_type="premade",
        )
        assert_matches_type(V1ListVoicesResponse, v1, path=["response"])

    @parametrize
    async def test_raw_response_list_voices(self, async_client: AsyncCasedev) -> None:
        response = await async_client.voice.v1.with_raw_response.list_voices()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v1 = await response.parse()
        assert_matches_type(V1ListVoicesResponse, v1, path=["response"])

    @parametrize
    async def test_streaming_response_list_voices(self, async_client: AsyncCasedev) -> None:
        async with async_client.voice.v1.with_streaming_response.list_voices() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v1 = await response.parse()
            assert_matches_type(V1ListVoicesResponse, v1, path=["response"])

        assert cast(Any, response.is_closed) is True
